fairly.file package
===================

Submodules
----------

fairly.file.local module
------------------------

.. automodule:: fairly.file.local
   :members:
   :undoc-members:
   :show-inheritance:

fairly.file.remote module
-------------------------

.. automodule:: fairly.file.remote
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fairly.file
   :members:
   :undoc-members:
   :show-inheritance:
